Class: Aws::CodeGuruProfiler::Types::GetFindingsReportAccountSummaryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruProfiler::Types::GetFindingsReportAccountSummaryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codeguruprofiler/types.rb
Overview
The structure representing the GetFindingsReportAccountSummaryResponse.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureGetFindingsReportAccountSummaryrequest. -
#report_summaries ⇒ Array<Types::FindingsReportSummary>
The return list of [
FindingsReportSummary][1] objects taht contain summaries of analysis results for all profiling groups in your AWS account.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future
GetFindingsReportAccountSummary request. When the results of a
GetFindingsReportAccountSummary request exceed maxResults, this
value can be used to retrieve the next page of results. This value
is null when there are no more results to return.
745 746 747 748 749 750 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 745 class GetFindingsReportAccountSummaryResponse < Struct.new( :next_token, :report_summaries) SENSITIVE = [] include Aws::Structure end |
#report_summaries ⇒ Array<Types::FindingsReportSummary>
The return list of FindingsReportSummary objects taht
contain summaries of analysis results for all profiling groups in
your AWS account.
745 746 747 748 749 750 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 745 class GetFindingsReportAccountSummaryResponse < Struct.new( :next_token, :report_summaries) SENSITIVE = [] include Aws::Structure end |