Class: Aws::CodeGuruProfiler::Types::GetRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruProfiler::Types::GetRecommendationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codeguruprofiler/types.rb
Overview
The structure representing the GetRecommendationsRequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The start time of the profile to get analysis data about.
-
#locale ⇒ String
The language used to provide analysis.
-
#profiling_group_name ⇒ String
The name of the profiling group to get analysis data about.
-
#start_time ⇒ Time
The end time of the profile to get analysis data about.
Instance Attribute Details
#end_time ⇒ Time
The start time of the profile to get analysis data about. You must
specify startTime and endTime. This is specified using the ISO
8601 format. For example, 2020-06-01T13:15:02.001Z represents 1
millisecond past June 1, 2020 1:15:02 PM UTC.
950 951 952 953 954 955 956 957 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 950 class GetRecommendationsRequest < Struct.new( :end_time, :locale, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#locale ⇒ String
The language used to provide analysis. Specify using a string that
is one of the following BCP 47 language codes.
-
de-DE- German, Germany -
en-GB- English, United Kingdom -
en-US- English, United States -
es-ES- Spanish, Spain -
fr-FR- French, France -
it-IT- Italian, Italy -
ja-JP- Japanese, Japan -
ko-KR- Korean, Republic of Korea -
pt-BR- Portugese, Brazil -
zh-CN- Chinese, China -
zh-TW- Chinese, Taiwan
950 951 952 953 954 955 956 957 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 950 class GetRecommendationsRequest < Struct.new( :end_time, :locale, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#profiling_group_name ⇒ String
The name of the profiling group to get analysis data about.
950 951 952 953 954 955 956 957 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 950 class GetRecommendationsRequest < Struct.new( :end_time, :locale, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The end time of the profile to get analysis data about. You must
specify startTime and endTime. This is specified using the ISO
8601 format. For example, 2020-06-01T13:15:02.001Z represents 1
millisecond past June 1, 2020 1:15:02 PM UTC.
950 951 952 953 954 955 956 957 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 950 class GetRecommendationsRequest < Struct.new( :end_time, :locale, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |