Class: Aws::CodeGuruProfiler::Types::ListProfileTimesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruProfiler::Types::ListProfileTimesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codeguruprofiler/types.rb
Overview
The structure representing the listProfileTimesRequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The end time of the time range from which to list the profiles.
-
#max_results ⇒ Integer
The maximum number of profile time results returned by
ListProfileTimesin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListProfileTimesrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#order_by ⇒ String
The order (ascending or descending by start time of the profile) to use when listing profiles.
-
#period ⇒ String
The aggregation period.
-
#profiling_group_name ⇒ String
The name of the profiling group.
-
#start_time ⇒ Time
The start time of the time range from which to list the profiles.
Instance Attribute Details
#end_time ⇒ Time
The end time of the time range from which to list the profiles.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of profile time results returned by
ListProfileTimes in paginated output. When this parameter is used,
ListProfileTimes only returns maxResults results in a single
page with a nextToken response element. The remaining results of
the initial request can be seen by sending another
ListProfileTimes request with the returned nextToken value.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListProfileTimes request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues
from the end of the previous results that returned the nextToken
value.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#order_by ⇒ String
The order (ascending or descending by start time of the profile) to
use when listing profiles. Defaults to TIMESTAMP_DESCENDING.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#period ⇒ String
The aggregation period. This specifies the period during which an aggregation profile collects posted agent profiles for a profiling group. There are 3 valid values.
-
P1D— 1 day -
PT1H— 1 hour -
PT5M— 5 minutes
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#profiling_group_name ⇒ String
The name of the profiling group.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The start time of the time range from which to list the profiles.
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1157 class ListProfileTimesRequest < Struct.new( :end_time, :max_results, :next_token, :order_by, :period, :profiling_group_name, :start_time) SENSITIVE = [] include Aws::Structure end |