Class: Aws::CodeGuruProfiler::Types::ListProfilingGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruProfiler::Types::ListProfilingGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codeguruprofiler/types.rb
Overview
The structure representing the listProfilingGroupsRequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include_description ⇒ Boolean
A
Booleanvalue indicating whether to include a description. -
#max_results ⇒ Integer
The maximum number of profiling groups results returned by
ListProfilingGroupsin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListProfilingGroupsrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#include_description ⇒ Boolean
A Boolean value indicating whether to include a description. If
true, then a list of ProfilingGroupDescription objects
that contain detailed information about profiling groups is
returned. If false, then a list of profiling group names is
returned.
1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1232 class ListProfilingGroupsRequest < Struct.new( :include_description, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of profiling groups results returned by
ListProfilingGroups in paginated output. When this parameter is
used, ListProfilingGroups only returns maxResults results in a
single page along with a nextToken response element. The remaining
results of the initial request can be seen by sending another
ListProfilingGroups request with the returned nextToken value.
1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1232 class ListProfilingGroupsRequest < Struct.new( :include_description, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListProfilingGroups request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues
from the end of the previous results that returned the nextToken
value.
1232 1233 1234 1235 1236 1237 1238 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1232 class ListProfilingGroupsRequest < Struct.new( :include_description, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |