Class: Aws::CodeGuruProfiler::Types::ListProfilingGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeGuruProfiler::Types::ListProfilingGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codeguruprofiler/types.rb
Overview
The structure representing the listProfilingGroupsResponse.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureListProfilingGroupsrequest. -
#profiling_group_names ⇒ Array<String>
A returned list of profiling group names.
-
#profiling_groups ⇒ Array<Types::ProfilingGroupDescription>
A returned list [
ProfilingGroupDescription][1] objects.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future ListProfilingGroups
request. When the results of a ListProfilingGroups request exceed
maxResults, this value can be used to retrieve the next page of
results. This value is null when there are no more results to
return.
1273 1274 1275 1276 1277 1278 1279 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1273 class ListProfilingGroupsResponse < Struct.new( :next_token, :profiling_group_names, :profiling_groups) SENSITIVE = [] include Aws::Structure end |
#profiling_group_names ⇒ Array<String>
A returned list of profiling group names. A list of the names is
returned only if includeDescription is false, otherwise a list
of ProfilingGroupDescription objects is returned.
1273 1274 1275 1276 1277 1278 1279 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1273 class ListProfilingGroupsResponse < Struct.new( :next_token, :profiling_group_names, :profiling_groups) SENSITIVE = [] include Aws::Structure end |
#profiling_groups ⇒ Array<Types::ProfilingGroupDescription>
A returned list ProfilingGroupDescription objects. A list
of ProfilingGroupDescription objects is returned only if
includeDescription is true, otherwise a list of profiling group
names is returned.
1273 1274 1275 1276 1277 1278 1279 |
# File 'lib/aws-sdk-codeguruprofiler/types.rb', line 1273 class ListProfilingGroupsResponse < Struct.new( :next_token, :profiling_group_names, :profiling_groups) SENSITIVE = [] include Aws::Structure end |